@@ -41,8 +41,12 @@ static void dvb_cable_channel_real_setup_dvb_source (DVBChannel* base, GstElemen
 
 static char* dvb_cable_channel_real_to_string (DVBChannel* base) {
 	DVBCableChannel * self;
+	char* _tmp0;
+	char* _tmp1;
 	self = (DVBCableChannel*) base;
-	return g_strdup_printf ("%s:%u:%s:%u:%s:%s:%u:%u:%u", dvb_channel_get_Name (DVB_CHANNEL (self)), dvb_channel_get_Frequency (DVB_CHANNEL (self)), dvb_utils_get_nick_from_enum (DVB_TYPE_DVB_SRC_INVERSION, (gint) self->priv->_Inversion), self->priv->_SymbolRate, dvb_utils_get_nick_from_enum (DVB_TYPE_DVB_SRC_CODE_RATE, (gint) self->priv->_CodeRate), dvb_utils_get_nick_from_enum (DVB_TYPE_DVB_SRC_MODULATION, (gint) self->priv->_Modulation), dvb_channel_get_VideoPID (DVB_CHANNEL (self)), dvb_channel_get_AudioPID (DVB_CHANNEL (self)), dvb_channel_get_Sid (DVB_CHANNEL (self)));
+	_tmp0 = NULL;
+	_tmp1 = NULL;
+	return (_tmp1 = g_strdup_printf ("%s:%u:%s:%u:%s:%s:%u:%s:%u", dvb_channel_get_Name (DVB_CHANNEL (self)), dvb_channel_get_Frequency (DVB_CHANNEL (self)), dvb_utils_get_nick_from_enum (DVB_TYPE_DVB_SRC_INVERSION, (gint) self->priv->_Inversion), self->priv->_SymbolRate, dvb_utils_get_nick_from_enum (DVB_TYPE_DVB_SRC_CODE_RATE, (gint) self->priv->_CodeRate), dvb_utils_get_nick_from_enum (DVB_TYPE_DVB_SRC_MODULATION, (gint) self->priv->_Modulation), dvb_channel_get_VideoPID (DVB_CHANNEL (self)), _tmp0 = dvb_channel_get_audio_pids_string (DVB_CHANNEL (self)), dvb_channel_get_Sid (DVB_CHANNEL (self))), _tmp0 = (g_free (_tmp0), NULL), _tmp1);
 }
 
 
@@ -112,6 +116,7 @@ void dvb_cable_channel_set_Modulation (DVBCableChannel* self, DVBDvbSrcModulatio
 
 static void dvb_cable_channel_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	DVBCableChannel * self;
+	gpointer boxed;
 	self = DVB_CABLE_CHANNEL (object);
 	switch (property_id) {
 		case DVB_CABLE_CHANNEL_INVERSION:
