@@ -1,8 +1,6 @@
 
 #include <src/DeviceGroup.h>
 #include <gee/set.h>
-#include <stdlib.h>
-#include <string.h>
 #include <gee/collection.h>
 #include <gee/hashset.h>
 
@@ -12,6 +10,7 @@
 struct _DVBDeviceGroupPrivate {
 	guint _Id;
 	DVBDevice* _reference_device;
+	char* _Name;
 	GeeSet* devices;
 };
 
@@ -23,7 +22,8 @@ enum  {
 	DVB_DEVICE_GROUP_CHANNELS,
 	DVB_DEVICE_GROUP_RECORDINGS_DIRECTORY,
 	DVB_DEVICE_GROUP_TYPE,
-	DVB_DEVICE_GROUP_REFERENCE_DEVICE
+	DVB_DEVICE_GROUP_REFERENCE_DEVICE,
+	DVB_DEVICE_GROUP_NAME
 };
 static GType dvb_device_group_real_get_element_type (GeeIterable* base);
 static GeeIterator* dvb_device_group_real_iterator (GeeIterable* base);
@@ -58,6 +58,7 @@ DVBDeviceGroup* dvb_device_group_construct (GType object_type, guint id, DVBDevi
 	g_value_set_object (&__params_it->value, reference_device);
 	__params_it++;
 	self = g_object_newv (object_type, __params_it - __params, __params);
+	dvb_channel_list_set_group_id (dvb_device_get_Channels (self->priv->_reference_device), id);
 	while (__params_it > __params) {
 		--__params_it;
 		g_value_unset (&__params_it->value);
@@ -97,7 +98,7 @@ gboolean dvb_device_group_add (DVBDeviceGroup* self, DVBDevice* device) {
 	g_return_val_if_fail (self != NULL, FALSE);
 	g_return_val_if_fail (device != NULL, FALSE);
 	if (dvb_device_get_Type (device) != dvb_device_group_get_Type (self)) {
-		g_warning ("DeviceGroup.vala:63: Cannot add device, because it is not of same type");
+		g_warning ("DeviceGroup.vala:65: Cannot add device, because it is not of same type");
 		return FALSE;
 	}
 	/* Set settings from reference device*/
@@ -214,6 +215,23 @@ static void dvb_device_group_set_reference_device (DVBDeviceGroup* self, DVBDevi
 }
 
 
+const char* dvb_device_group_get_Name (DVBDeviceGroup* self) {
+	g_return_val_if_fail (self != NULL, NULL);
+	return self->priv->_Name;
+}
+
+
+void dvb_device_group_set_Name (DVBDeviceGroup* self, const char* value) {
+	char* _tmp2;
+	const char* _tmp1;
+	g_return_if_fail (self != NULL);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_Name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : g_strdup (_tmp1)), self->priv->_Name = (g_free (self->priv->_Name), NULL), _tmp2);
+	g_object_notify ((GObject *) self, "Name");
+}
+
+
 static guint _dvb_device_hash_ghash_func (void* key) {
 	return dvb_device_hash (key);
 }
@@ -245,6 +263,7 @@ static GObject * dvb_device_group_constructor (GType type, guint n_construct_pro
 
 static void dvb_device_group_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	DVBDeviceGroup * self;
+	gpointer boxed;
 	self = DVB_DEVICE_GROUP (object);
 	switch (property_id) {
 		case DVB_DEVICE_GROUP_SIZE:
@@ -265,6 +284,9 @@ static void dvb_device_group_get_property (GObject * object, guint property_id,
 		case DVB_DEVICE_GROUP_REFERENCE_DEVICE:
 		g_value_set_object (value, dvb_device_group_get_reference_device (self));
 		break;
+		case DVB_DEVICE_GROUP_NAME:
+		g_value_set_string (value, dvb_device_group_get_Name (self));
+		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
 		break;
@@ -282,6 +304,9 @@ static void dvb_device_group_set_property (GObject * object, guint property_id,
 		case DVB_DEVICE_GROUP_REFERENCE_DEVICE:
 		dvb_device_group_set_reference_device (self, g_value_get_object (value));
 		break;
+		case DVB_DEVICE_GROUP_NAME:
+		dvb_device_group_set_Name (self, g_value_get_string (value));
+		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
 		break;
@@ -302,6 +327,7 @@ static void dvb_device_group_class_init (DVBDeviceGroupClass * klass) {
 	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_DEVICE_GROUP_RECORDINGS_DIRECTORY, g_param_spec_object ("RecordingsDirectory", "RecordingsDirectory", "RecordingsDirectory", G_TYPE_FILE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_DEVICE_GROUP_TYPE, g_param_spec_enum ("Type", "Type", "Type", DVB_TYPE_ADAPTER_TYPE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_DEVICE_GROUP_REFERENCE_DEVICE, g_param_spec_object ("reference-device", "reference-device", "reference-device", DVB_TYPE_DEVICE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_DEVICE_GROUP_NAME, g_param_spec_string ("Name", "Name", "Name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
@@ -321,6 +347,7 @@ static void dvb_device_group_finalize (GObject* obj) {
 	DVBDeviceGroup * self;
 	self = DVB_DEVICE_GROUP (obj);
 	(self->priv->_reference_device == NULL) ? NULL : (self->priv->_reference_device = (g_object_unref (self->priv->_reference_device), NULL));
+	self->priv->_Name = (g_free (self->priv->_Name), NULL);
 	(self->priv->devices == NULL) ? NULL : (self->priv->devices = (g_object_unref (self->priv->devices), NULL));
 	G_OBJECT_CLASS (dvb_device_group_parent_class)->finalize (obj);
 }
