@@ -37,13 +37,15 @@ struct _DVBManagerClass {
 
 
 DVBManager* dvb_manager_get_instance (void);
+void dvb_manager_shutdown (void);
 char** dvb_manager_GetScannerForDevice (DVBManager* self, guint adapter, guint frontend, int* result_length1);
 guint* dvb_manager_GetRegisteredDeviceGroups (DVBManager* self, int* result_length1);
 char* dvb_manager_GetTypeOfDeviceGroup (DVBManager* self, guint group_id);
 char* dvb_manager_GetRecorder (DVBManager* self, guint group_id);
-gboolean dvb_manager_AddDeviceToNewGroup (DVBManager* self, guint adapter, guint frontend, const char* channels_conf, const char* recordings_dir);
+gboolean dvb_manager_AddDeviceToNewGroup (DVBManager* self, guint adapter, guint frontend, const char* channels_conf, const char* recordings_dir, const char* name);
 gboolean dvb_manager_AddDeviceToExistingGroup (DVBManager* self, guint adapter, guint frontend, guint group_id);
 gboolean dvb_manager_RemoveDeviceFromGroup (DVBManager* self, guint adapter, guint frontend, guint group_id);
+char* dvb_manager_GetDeviceGroupName (DVBManager* self, guint group_id);
 char* dvb_manager_GetChannelList (DVBManager* self, guint group_id);
 char** dvb_manager_GetDeviceGroupMembers (DVBManager* self, guint group_id, int* result_length1);
 char* dvb_manager_GetNameOfRegisteredDevice (DVBManager* self, guint adapter, guint frontend);
